@@ -483,7 +483,7 @@ static int open_db_writing(void) {/*{{{*/
 
     if (!tries) {
         (void) close(db);
-        errormsg(0, -1, "can't create exlusive lock on cache database");
+        errormsg(0, -1, "can't create exclusive lock on cache database");
         return -1;
     }
 
